<?php
/**
 * DeubertIt
 *
 * LICENSE: Redistribution and use in source and binary forms, with or without
 * modifications, are not permitted.
 *
 * @copyright Deubert IT-Solutions © 2020 All rights reserved
 * @package DeubertIt\ElasticApmZfMvc
 */

namespace DeubertIt\ElasticApmZfMvc\Tests\Controller\Plugin;

use DeubertIt\ElasticApmZfMvc\Controller\Plugin\ElasticApmZfMvcPlugin;
use DeubertIt\ElasticApmZfMvc\ElasticApmZfMvc;
use DeubertIt\ElasticApmZfMvc\Tests\TestCase;
use PhilKra\Agent;
use PhilKra\Events\Transaction;

/**
 * Class ElasticApmZfMvcPluginTests
 * @package DeubertIt\ElasticApmZfMvc\Tests\Controller\Plugin
 *
 * @author Ivan Petrov <ivan.petrov@deubert.it>
 */
class ElasticApmZfMvcPluginTests extends TestCase
{
    public function testCreateTransaction()
    {
        $request = new \Zend_Controller_Request_HttpTestCase();
        $request->setMethod(\Zend_Http_Client::POST);
        $request->setModuleName('elasticapmmodule');
        $request->setControllerName('elasticapmcontroller');
        $request->setActionName('elasticapmaction');
        $request->setRequestUri('/elasticapmmodule/elasticapmcontroller/elasticapmaction');
        $request->setDispatched(true);

        $response = new \Zend_Controller_Response_Http();

        $plugin = new ElasticApmZfMvcPlugin();
        $plugin->setRequest($request);
        $plugin->setResponse($response);

        /** @var Agent $agent */
        $agent = $this->getElasticApmAgentMock();
        
        $transactionName = ElasticApmZfMvc::getNameFromRequest($request);

        $transactionMock = $this->getMockBuilder(Transaction::class)
            ->disableOriginalConstructor()
            ->getMock();
        $transactionMock->method('getTransactionName')
            ->willReturn($transactionName);

        $agent->method('getTransaction')
            ->willReturn($transactionMock);
        $agent->method('startTransaction')
            ->willReturn($transactionMock);

        ElasticApmZfMvc::setAgent($agent);

        $plugin->preDispatch($request);
        
        $transaction = $agent->getTransaction($transactionName);

        $this->assertInstanceOf(Transaction::class, $transaction);
        $this->assertEquals($transactionName, $transaction->getTransactionName());
    }
}
