<?php
/**
 * DeubertIt
 *
 * LICENSE: Redistribution and use in source and binary forms, with or without
 * modifications, are not permitted.
 *
 * @copyright Deubert IT-Solutions © 2020 All rights reserved
 * @package DeubertIt\ElasticApmZfMvc
 */

namespace DeubertIt\ElasticApmZfMvc\Tests;

use DeubertIt\ElasticApm\Base;
use DeubertIt\ElasticApmZfMvc\ElasticApmZfMvc;
use PhilKra\Agent;
use PhilKra\Events\Transaction;

/**
 * Class ElasticApmZfMvcTests
 * @package DeubertIt\ElasticApmZfMvc\Tests
 *
 * @author Ivan Petrov <ivan.petrov@deubert.it>
 */
class ElasticApmZfMvcTests extends TestCase
{
    /**
     * @var Agent
     */
    protected $agent;

    public function setUp()
    {
        $agent = $this->getElasticApmAgentMock();
        \Zend_Registry::set(Base::ELASTIC_APM_REGISTRYKEY, $agent);
        $this->agent = $agent;
    }

    public function testGetDefaultAgent()
    {
        $elasticApmAgent = ElasticApmZfMvc::getAgent();
        $this->assertEquals($elasticApmAgent, $this->agent);
    }

    public function testTransaction()
    {
        $transactionMock = $this->getMockBuilder(Transaction::class)
            ->disableOriginalConstructor()
            ->getMock();
        $transactionMock->method('getTransactionName')
            ->willReturn('transaction-name');

        $agent = $this->agent;
        $agent->method('getTransaction')
            ->willReturn($transactionMock);
        $agent->method('startTransaction')
            ->willReturn($transactionMock);

        ElasticApmZfMvc::setAgent($agent);
        $transaction = ElasticApmZfMvc::start('transaction-name');

        $this->assertInstanceOf(Transaction::class, $transaction);
        $this->assertEquals($agent->getTransaction('transaction-name'), $transaction);
        $this->assertEquals('transaction-name', $transaction->getTransactionName());
    }
}
